@@ -40,6 +40,10 @@ class SphinxEnvironment(Environment):
     def changelog_sections(self):
         return self.sphinx_env.config.changelog_sections
 
+    @property
+    def changelog_caption_class(self):
+        return self.sphinx_env.config.changelog_caption_class
+
     @property
     def changelog_inner_tag_sort(self):
         return self.sphinx_env.config.changelog_inner_tag_sort
@@ -48,6 +52,10 @@ class SphinxEnvironment(Environment):
     def changelog_hide_sections_from_tags(self):
         return self.sphinx_env.config.changelog_hide_sections_from_tags
 
+    @property
+    def changelog_hide_tags_in_entry(self):
+        return self.sphinx_env.config.changelog_hide_tags_in_entry
+
     @property
     def changelog_render_ticket(self):
         return self.sphinx_env.config.changelog_render_ticket
@@ -102,8 +110,10 @@ def setup(app):
     app.add_directive("change", ChangeDirective)
     app.add_directive("changelog_imports", ChangeLogImportDirective)
     app.add_config_value("changelog_sections", [], "env")
+    app.add_config_value("changelog_caption_class", "caption", "env")
     app.add_config_value("changelog_inner_tag_sort", [], "env")
     app.add_config_value("changelog_hide_sections_from_tags", False, "env")
+    app.add_config_value("changelog_hide_tags_in_entry", False, "env")
     app.add_config_value("changelog_render_ticket", None, "env")
     app.add_config_value("changelog_render_pullreq", None, "env")
     app.add_config_value("changelog_render_changeset", None, "env")
